@@ -1,7 +1,7 @@
 #!/usr/bin/r -t
 #       hey emacs, please make this use  -*- tab-width: 4 -*-
 #
-# Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2010 - 2012  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -22,7 +22,9 @@
 	gc()
 }
 
-if( Rcpp:::capabilities()[["Rcpp modules"]] ) {
+.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
+
+if( .runThisTest && Rcpp:::capabilities()[["Rcpp modules"]] ) {
 
 test.Module <- function(){
 
